@@ -133,4 +133,18 @@ def apply_patch():
             f.write(line+"\n")
             if "def _log_request(cls, res: Response, **kwargs):" in line:
                 f.write("        return\n")
-    os.environ["COGNITE_DISABLE_GZIP"] = "1"
\ No newline at end of file
+    os.environ["COGNITE_DISABLE_GZIP"] = "1"
+
+import asyncio
+
+async def get_token():
+    import js
+    op = js.indexedDB.open("DSHubDB", 1)
+    await asyncio.sleep(0.1)
+    db = op.result
+    tx = db.transaction("TokenStore", "readonly")
+    store = tx.objectStore("TokenStore")
+    index = store.index("TokenIndex")
+    token = store.get(1)
+    await asyncio.sleep(0.1)
+    return token.result.token
